package com.willalp.apply.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.willalp.apply.domain.HsSysApply;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 编码申请Mapper接口
 *
 * @author bjh
 * @date 2022-01-04
 */
public interface HsSysApplyMapper extends BaseMapper<HsSysApply>
{
    /**
     * 查询编码申请
     *
     * @param id 编码申请主键
     * @return 编码申请
     */
    public HsSysApply selectHsSysApplyById(Long id);

    /**
     * 查询编码申请列表
     *
     * @param hsSysApply 编码申请
     * @return 编码申请集合
     */
    public List<HsSysApply> selectHsSysApplyList(HsSysApply hsSysApply);

    public Map<String,Object> selectCodeById(long id);

    public List<Map<String,Object>> selectHsSysLevelList(String id);

    public void updateSysCodename(@Param("levelid") String levelid, @Param("i") long i, @Param("value") String value);

    public List<Map<String,Object>> checkApplyData(String codeapply);

    /**
     * 新增编码申请
     *
     * @param hsSysApply 编码申请
     * @return 结果
     */
    public int insertHsSysApply(HsSysApply hsSysApply);

    /**
     * 修改编码申请
     *
     * @param hsSysApply 编码申请
     * @return 结果
     */
    public int updateHsSysApply(HsSysApply hsSysApply);

    /**
     * 删除编码申请
     *
     * @param id 编码申请主键
     * @return 结果
     */
    public int deleteHsSysApplyById(Long id);

    /**
     * 批量删除编码申请
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHsSysApplyByIds(Long[] ids);
}
